@@ -1,25 +1,24 @@
 use strict;
 use warnings;
+
 package Test::Mocha;
 {
-  $Test::Mocha::VERSION = '0.21';
+  $Test::Mocha::VERSION = '0.50';
 }
 # ABSTRACT: Test Spy/Stub Framework
 
 
 use Carp     qw( croak );
 use Exporter qw( import );
-use Test::Mocha::Inspect;
 use Test::Mocha::Mock;
-use Test::Mocha::Stub;
 use Test::Mocha::Types 'NumRange', Mock => { -as => 'MockType' };
-use Test::Mocha::Util qw( getattr );
-use Test::Mocha::Verify;
-use Types::Standard qw( ArrayRef HashRef Num slurpy );
+use Test::Mocha::Util qw( getattr get_method_call is_called );
+use Types::Standard   qw( ArrayRef HashRef Num slurpy );
 
 our @EXPORT = qw(
     mock
     stub
+    called_ok
     verify
     inspect
     inspect_all
@@ -28,6 +27,15 @@ our @EXPORT = qw(
     SlurpyHash
 );
 
+# croak() messages should not trace back to Mocha modules
+$Carp::Internal{$_}++ foreach qw(
+    Test::Mocha
+    Test::Mocha::Inspect
+    Test::Mocha::Mock
+    Test::Mocha::Util
+    Test::Mocha::Verify
+);
+
 
 use constant {
     SlurpyArray => slurpy(ArrayRef),
@@ -41,17 +49,60 @@ sub mock {
 
 
 sub stub {
-    my ($mock) = @_;
+    my ( $arg ) = @_;
 
-    croak 'stub() must be given a mock object'
-        unless defined $mock && MockType->check($mock);
+    if ( defined $arg ) {
+        if ( MockType->check($arg) ) {
+            warnings::warnif(
+                'deprecated',
+                'Calling stub() with a mock object parameter is deprecated; pass it a coderef instead'
+            );
+            require Test::Mocha::Stub;
+            return Test::Mocha::Stub->new( mock => $arg );
+        }
+        elsif ( ref($arg) eq 'CODE' ) {
+            $Test::Mocha::Mock::num_method_calls = 0;
+            my $method_call = get_method_call($arg);
+            my $stubs = getattr( $method_call->invocant, 'stubs' );
+            unshift @{ $stubs->{ $method_call->name } }, $method_call;
 
-    return Test::Mocha::Stub->new(mock => $mock);
+            return Test::Mocha::MethodStub->cast( $method_call );
+        }
+    }
+    croak 'stub() must be given a coderef';
 }
 
 
+sub called_ok {
+    my ( $coderef, %options ) = _get_called_ok_args(@_);
+
+    croak 'called_ok() must be given a coderef'
+        unless defined($coderef) && ref($coderef) eq 'CODE';
+
+    $Test::Mocha::Mock::num_method_calls = 0;
+    is_called( get_method_call($coderef), %options );
+    return;
+}
+
+# verify() has been retained for backwards compatibility only
+
 sub verify {
-    my $mock = shift;
+    # uncoverable pod
+    my ( $mock, %options ) = _get_called_ok_args(@_);
+
+    warnings::warnif(
+        'deprecated',
+        'verify() is deprecated; use called_ok() instead'
+    );
+    croak 'verify() must be given a mock object'
+        unless defined($mock) && MockType->check($mock);
+
+    require Test::Mocha::Verify;
+    return Test::Mocha::Verify->new( mock => $mock, %options );
+}
+
+sub _get_called_ok_args {
+    my $coderef = shift;
     my $test_name;
     $test_name = pop if (@_ % 2 == 1);
     my %options = @_;
@@ -59,54 +110,63 @@ sub verify {
     # set default option if none given
     $options{times} = 1 if keys %options == 0;
 
-    croak 'verify() must be given a mock object'
-        unless defined $mock && MockType->check($mock);
-
     croak 'You can set only one of these options: '
-        . join ', ', map {"'$_'"} keys %options
+        . join ', ', map { "'$_'" } keys %options
         unless keys %options == 1;
 
-    if (defined $options{times}) {
+    if ( defined $options{times} ) {
         croak "'times' option must be a number"
             unless Num->check( $options{times} );
     }
-    elsif (defined $options{at_least}) {
+    elsif ( defined $options{at_least} ) {
         croak "'at_least' option must be a number"
             unless Num->check( $options{at_least} );
     }
-    elsif (defined $options{at_most}) {
+    elsif ( defined $options{at_most} ) {
         croak "'at_most' option must be a number"
             unless Num->check( $options{at_most} );
     }
-    elsif (defined $options{between}) {
+    elsif ( defined $options{between} ) {
         croak "'between' option must be an arrayref "
             . "with 2 numbers in ascending order"
             unless NumRange->check( $options{between} );
     }
     else {
-        my ($option) = keys %options;
-        croak "verify() was given an invalid option: '$option'";
+        my ( $option ) = keys %options;
+        croak "called_ok() was given an invalid option: '$option'";
     }
+    $options{ test_name } = $test_name if defined $test_name;
 
-    # set test name if given
-    $options{test_name} = $test_name if defined $test_name;
-
-    return Test::Mocha::Verify->new(mock => $mock, %options);
+    return ( $coderef, %options );
 }
 
 
 sub inspect {
-    my ($mock) = @_;
+    my ( $arg ) = @_;
 
-    croak 'inspect() must be given a mock object'
-        unless defined $mock && MockType->check($mock);
-
-    return Test::Mocha::Inspect->new(mock => $mock);
+    if ( defined $arg ) {
+        if ( MockType->check($arg) ) {
+            warnings::warnif(
+                'deprecated',
+                'Calling inspect() with a mock object parameter is deprecated; pass it a coderef instead'
+            );
+            require Test::Mocha::Inspect;
+            return Test::Mocha::Inspect->new( mock => $arg );
+        }
+        elsif ( ref($arg) eq 'CODE' ) {
+            $Test::Mocha::Mock::num_method_calls = 0;
+            my $method_call = get_method_call($arg);
+            my $mock        = $method_call->invocant;
+            my $calls       = getattr( $mock, 'calls' );
+            return grep { $method_call->satisfied_by($_) } @$calls;
+        }
+    }
+    croak 'inspect() must be given a coderef';
 }
 
 
 sub inspect_all {
-    my ($mock) = @_;
+    my ( $mock ) = @_;
 
     croak 'inspect_all() must be given a mock object'
         unless defined $mock && MockType->check($mock);
@@ -116,13 +176,12 @@ sub inspect_all {
 
 
 sub clear {
-    my ($mock) = @_;
+    my @mocks = @_;
 
-    croak 'clear() must be given a mock object'
-        unless defined $mock && MockType->check($mock);
+    croak 'clear() must be given one or more mock objects'
+        if !@mocks || grep { ! MockType->check($_) } @mocks;
 
-    my $calls = getattr($mock, 'calls');
-    @$calls = ();
+    @{ getattr( $_, 'calls' ) } = ( ) foreach @mocks;
 
     return;
 }
@@ -139,7 +198,7 @@ Test::Mocha - Test Spy/Stub Framework
 
 =head1 VERSION
 
-version 0.21
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -154,7 +213,7 @@ other objects.
     my $warehouse = mock;
 
     # stub method calls (with type constraint for matching argument)
-    stub($warehouse)->has_inventory($item1, Int)->returns(1);
+    stub( sub { $warehouse->has_inventory($item1, Int) } )->returns(1);
 
     # execute the code under test
     my $order = Order->new(item => $item1, quantity => 50);
@@ -162,7 +221,10 @@ other objects.
 
     # verify interactions with the dependent object
     ok( $order->is_filled, 'Order is filled' );
-    verify( $warehouse, '... and inventory is removed' )->remove_inventory($item1, 50);
+    called_ok(
+        sub { $warehouse->remove_inventory($item1, 50) },
+        '... and inventory is removed'
+    );
 
     # clear the invocation history
     clear($warehouse);
@@ -216,13 +278,13 @@ return C<undef> (in scalar context) or an empty list (in list context).
 You can stub C<ref()> to specify the value it should return (see below for
 more info about stubbing).
 
-    stub($mock)->ref->returns('AnyClass');
+    stub( sub{ $mock->ref } )->returns('AnyClass');
     is( $mock->ref, 'AnyClass' );
     is( ref($mock), 'AnyClass' );
 
 =head2 stub
 
-    stub($mock)->method(@args)->returns|dies|executes($response)
+    stub( sub { $mock->method(@args) } )->returns|throws|executes($response)
 
 By default, the mock object already acts as a stub that accepts any method
 call and returns C<undef>. However, you can use C<stub()> to tell a method to
@@ -234,14 +296,14 @@ give an alternative response. You can specify 3 types of responses:
 
 Specifies that a stub should return 1 or more values.
 
-    stub($mock)->method(@args)->returns(1, 2, 3);
+    stub( sub { $mock->method(@args) } )->returns(1, 2, 3);
     is_deeply( [ $mock->method(@args) ], [ 1, 2, 3 ] );
 
-=item C<dies($message)>
+=item C<throws($message)>
 
 Specifies that a stub should raise an exception.
 
-    stub($mock)->method(@args)->dies('exception');
+    stub( sub { $mock->method(@args) } )->throws('exception');
     ok( exception { $mock->method(@args) } );
 
 =item C<executes($coderef)>
@@ -251,8 +313,8 @@ in the method call are passed on to the callback.
 
     my @returns = qw( first second third );
 
-    stub($list)->get(Int)->executes(sub {
-        my ($self, $i) = @_;
+    stub( sub { $list->get(Int) } )->executes(sub {
+        my ( $self, $i ) = @_;
         die "index out of bounds" if $i < 0;
         return $returns[$i];
     });
@@ -267,17 +329,20 @@ in the method call are passed on to the callback.
 A stub applies to the exact method and arguments specified (but see also
 L</"ARGUMENT MATCHING"> for a shortcut around this).
 
-    stub($list)->get(0)->returns('first');
-    stub($list)->get(1)->returns('second');
+    stub( sub { $list->get(0) } )->returns('first');
+    stub( sub { $list->get(1) } )->returns('second');
 
-    is( $list->get(0), 'first' );
+    is( $list->get(0), 'first'  );
     is( $list->get(1), 'second' );
-    is( $list->get(2), undef );
+    is( $list->get(2),  undef   );
 
 Chain responses together to provide a consecutive series.
 
-    stub($iterator)->next
-        ->returns(1)->returns(2)->returns(3)->dies('exhuasted');
+    stub( sub { $iterator->next } )
+        ->returns(1)
+        ->returns(2)
+        ->returns(3)
+        ->throws('exhuasted');
 
     ok( $iterator->next == 1 );
     ok( $iterator->next == 2 );
@@ -286,23 +351,23 @@ Chain responses together to provide a consecutive series.
 
 The last stubbed response will persist until it is overridden.
 
-    stub($warehouse)->has_inventory($item, 10)->returns(1);
+    stub( sub { $warehouse->has_inventory($item, 10) } )->returns(1);
     ok( $warehouse->has_inventory($item, 10) ) for 1 .. 5;
 
-    stub($warehouse)->has_inventory($item, 10)->returns(0);
+    stub( sub { $warehouse->has_inventory($item, 10) } )->returns(0);
     ok( !$warehouse->has_inventory($item, 10) ) for 1 .. 5;
 
-=head2 verify
+=head2 called_ok
 
-    verify($mock, [%option], [$test_name])->method(@args)
+    called_ok( sub { $mock->method(@args) }, [%option], [$test_name] )
 
-C<verify()> is used to test the interactions with the mock object. You can use
-it to verify that the correct methods were called, with the correct set of
-arguments, and the correct number of times. C<verify()> plays nicely with
+C<called_ok()> is used to test the interactions with the mock object. You can
+use it to verify that the correct method was called, with the correct set of
+arguments, and the correct number of times. C<called_ok()> plays nicely with
 L<Test::Simple> and Co - it will print the test result along with your other
-tests and calls to C<verify()> are counted in the test plan.
+tests and you must count calls to C<called_ok()> in your test plans.
 
-    verify($warehouse)->remove($item, 50);
+    called_ok( sub { $warehouse->remove($item, 50) } );
     # prints: ok 1 - remove("book", 50) was called 1 time(s)
 
 An option may be specified to constrain the test.
@@ -314,31 +379,31 @@ An option may be specified to constrain the test.
 Specifies the number of times the given method is expected to be called.
 The default is 1 if no other option is specified.
 
-    verify( $mock, times => 3 )->method(@args)
-    # print: ok 1 - method(@args) was called 3 time(s)
+    called_ok( sub { $mock->method(@args) }, times => 3 )
+    # prints: ok 1 - method(@args) was called 3 time(s)
 
 =item C<at_least>
 
 Specifies the minimum number of times the given method is expected to be
 called.
 
-    verify( $mock, at_least => 3 )->method(@args)
-    # print: ok 1 - method(@args) was called at least 3 time(s)
+    called_ok( sub { $mock->method(@args) }, at_least => 3 )
+    # prints: ok 1 - method(@args) was called at least 3 time(s)
 
 =item C<at_most>
 
 Specifies the maximum number of times the given method is expected to be
 called.
 
-    verify( $mock, at_most => 5 )->method(@args)
-    # print: ok 1 - method(@args) was called at most 5 time(s)
+    called_ok( sub { $mock->method(@args) }, at_most => 5 )
+    # prints: ok 1 - method(@args) was called at most 5 time(s)
 
 =item C<between>
 
 Specifies the minimum and maximum number of times the given method is
 expected to be called.
 
-    verify( $mock, between => [3, 5] )->method(@args)
+    called_ok( sub { $mock->method(@args) }, between => [3, 5] )
     # prints: ok 1 - method(@args) was called between 3 and 5 time(s)
 
 =back
@@ -346,17 +411,24 @@ expected to be called.
 An optional C<$test_name> may be specified to be printed instead of the
 default.
 
-    verify( $warehouse, 'inventory removed' )->remove_inventory($item, 50);
+    called_ok(
+        sub { $warehouse->remove_inventory($item, 50) },
+        'inventory removed'
+    );
     # prints: ok 1 - inventory removed
 
-    verify( $warehouse, times => 0, 'inventory not removed' )->remove_inventory($item, 50);
+    called_ok(
+        sub { $warehouse->remove_inventory($item, 50) },
+        times => 0,
+        'inventory not removed'
+    );
     # prints: ok 2 - inventory not removed
 
 =head2 inspect
 
-    @method_calls = inspect($mock)->method(@args)
+    @method_calls = inspect( sub { $mock->method(@args) } )
 
-    ( $method_call ) = inspect($warehouse)->remove_inventory(Str, Int);
+    ( $method_call ) = inspect( sub { $warehouse->remove_inventory(Str, Int) } );
 
     is( $method_call->name,            'remove_inventory' );
     is_deeply( [$method_call->args],   ['book', 50] );
@@ -364,8 +436,9 @@ default.
     is( "$method_call", 'remove_inventory("book", 50) called at test.pl line 5' );
 
 C<inspect()> returns a list of method calls matching the given method call
-specification. It can be useful for debugging failed C<verify()> calls. Or use
-it in place of a complex C<verify()> call to break it down into smaller tests.
+specification. It can be useful for debugging failed C<called_ok()> calls.
+Or use it in place of a complex C<called_ok()> call to break it down into
+smaller tests.
 
 The method call objects have the following accessor methods:
 
@@ -396,19 +469,21 @@ object. This is mainly used for debugging.
 
 =head2 clear
 
-    clear($mock)
+    clear(@mocks)
 
-Clears the method call history of the mock for it to be reused in another test.
-Note that this does not affect the stubbed methods.
+Clears the method call history for one or more mocks so that they can be
+reused in another test. Note that this does not affect the stubbed methods.
 
 =for Pod::Coverage SlurpyArray SlurpyHash
 
+=for Pod::Coverage verify
+
 =head1 ARGUMENT MATCHING
 
 Argument matchers may be used in place of specifying exact method arguments.
 They allow you to be more general and will save you much time in your
 method specifications to stubs and verifications. Argument matchers may be used
-with C<stub()>, C<verify()> and C<inspect>.
+with C<stub()>, C<called_ok()> and C<inspect>.
 
 =head2 Pre-defined types
 
@@ -419,12 +494,12 @@ L<MooseX::Types::Structured> will also work.)
     use Types::Standard qw( Any );
 
     my $mock = mock;
-    stub($mock)->foo(Any)->returns('ok');
+    stub( sub { $mock->foo(Any) } )->returns('ok');
 
     print $mock->foo(1);        # prints: ok
     print $mock->foo('string'); # prints: ok
 
-    verify($mock, times => 2)->foo(Defined);
+    called_ok( sub { $mock->foo(Defined) }, times => 2 );
     # prints: ok 1 - foo(Defined) was called 2 time(s)
 
 You may use the normal features of the types: parameterized and structured
@@ -439,7 +514,7 @@ use coercions).
 
     # parameterized type
     # prints: ok 1 - set(Int, StrMatch[(?^:^foo)]) was called 1 time(s)
-    verify($list)->set( Int, StrMatch[qr/^foo/] );
+    called_ok( sub { $list->set( Int, StrMatch[qr/^foo/] ) } );
 
 =head2 Self-defined types
 
@@ -447,11 +522,11 @@ You may also use your own types, defined using L<Type::Utils>.
 
     use Type::Utils -all;
 
-    # naming the type means it will be printed nicely in the verify() output
+    # naming the type means it will be printed nicely in called_ok()'s output
     my $positive_int = declare 'PositiveInt', as Int, where { $_ > 0 };
 
     # prints: ok 2 - set(PositiveInt, Any) was called 1 time(s)
-    verify($list)->set( $positive_int, Any );
+    called_ok( sub { $list->set($positive_int, Any) } );
 
 =head2 Argument slurping
 
@@ -459,8 +534,8 @@ C<SlurpyArray> and C<SlurpyHash> are special argument matchers exported by
 Test::Mocha that you can use when you don't care what arguments are used.
 They will just slurp up the remaining arguments as though they match.
 
-    verify($list)->set( SlurpyArray );
-    verify($list)->set( Int, SlurpyHash );
+    called_ok( sub { $list->set(SlurpyArray) } );
+    called_ok( sub { $list->set(Int, SlurpyHash) } );
 
 Because they consume the remaining arguments, you can't use further argument
 validators after them. But you can, of course, use them before. Note also that
