@@ -1,6 +1,6 @@
 package Test::Mocha::MethodCall;
 {
-  $Test::Mocha::MethodCall::VERSION = '0.21';
+  $Test::Mocha::MethodCall::VERSION = '0.50';
 }
 # ABSTRACT: Objects to represent method calls
 
@@ -11,25 +11,29 @@ use Test::Mocha::Method;
 
 our @ISA = qw( Test::Mocha::Method );
 
-use overload '""' => \&stringify, fallback => 1;
-
 sub new {
     # uncoverable pod
     my ($class, %args) = @_;
     # caller should be an arrayref tuple [file, line]
+    ### assert: defined $args{invocant}
     ### assert: defined $args{caller}
     ### assert: ref $args{caller} eq 'ARRAY' && @{$args{caller}} == 2
     return $class->SUPER::new(%args);
 }
 
+sub invocant {
+    # uncoverable pod
+    return $_[0]->{invocant};
+}
+
 sub caller {
     # uncoverable pod
     return @{ $_[0]->{caller} };
 }
 
-sub stringify {
+sub stringify_long {
     # uncoverable pod
-    my ($self) = @_;
+    my ( $self ) = @_;
     return sprintf(
         '%s called at %s line %d',
         $self->SUPER::stringify,
